/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.fabric.builder;

import org.fabric3.spi.builder.BuilderException;
import org.fabric3.spi.builder.WiringException;
import org.fabric3.spi.model.physical.PhysicalWireDefinition;

/**
 * Connects a source to a target via wire.
 *
 * @version $$Rev: 4227 $$ $$Date: 2008-05-15 14:18:04 -0700 (Thu, 15 May 2008) $$
 */
public interface Connector {

    /**
     * Performs the connect operation.
     *
     * @param definition metadata describing the wire to create
     * @throws BuilderException if an error connecting the components occurs.
     */
    void connect(PhysicalWireDefinition definition) throws BuilderException;


    /**
     * Performs the disconnect operation
     * @param definition
     */
    void disconnect(PhysicalWireDefinition definition) throws BuilderException;
}
